\name{balloon}
\docType{data}
\alias{balloon}   
\title{Data from a weather balloon}
\description{
The data consist of 4984 observations taken from a balloon about 30 kilometres
above the surface of the earth. The outliers are caused by the fact that the
balloon slowly rotates, causing the ropes from which the measuring instrument
is suspended to cut off the direct radiation from the sun. 
}
\usage{data(djdata)}
\format{ A one-dimensional data set of size 4984 }
\source{ Davies, L. and Gather, U. (1993), The Identification of Multiple
   Outliers. 
\emph{JASA}
  \bold{88}, 782--801.
}
\examples{
data(balloon)
plot(balloon)
}
\keyword{datasets}
\eof
\name{dclaw}
\alias{dclaw}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{The Claw Distribution}
\description{
Generates a sample from the claw distribution.}
}
\usage{
dclaw(x)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{Vector of points where the claw density is evaluated.}
}
J.S. Marron and M.P. Wand.
\newblock Exact mean integrated squared error.
\newblock {\em Annals of Statistics}, 20:712--736, 1992.
\references{Marron, J. S. and Wand, M. P. (1992) Exact mean integrated squared error}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{rclaw}}}

\examples{
plot(dclaw(seq(-3,3,len=1000)),ty="l")
}
\keyword{ distribution  }% at least one, from doc/KEYWORDS
\eof
\name{djdata}
\docType{data}
\alias{djdoppler}
\alias{djheavisine}
\alias{djblocks} 
\alias{djbumps}   
\title{Donoho-Johnstone test signals}
\description{
Four samples, each of size 2048 from Donoho and Johnstone's famous
signals commonly used as test beds for smoothing methods.
}
\usage{data(djdata)}
\format{ Four one-dimensional data sets, each of size 2048 }
\source{ Donoho, D. L. et al (1995) Wavelet Shrinkage: Asymptopia?
\emph{Journal of the Royal Statistical Society}
  series B, \bold{57}, 301--337.
}
\examples{
data(djdata)
par(mfrow=c(2,2))
plot(djdoppler)
plot(djheavisine)
plot(djblocks)  
plot(djbumps)
}
\keyword{datasets}
\eof
\name{frun}
\alias{frun}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Runs and local extremes}
\description{
Calculation of bounds for functions such that the residuals
satisfy a run criterion}
\usage{
frun(y, ..., alpha = 0.5, r = 0, mr = 0)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{the data}
  \item{\dots}{an optional argument which specifies
the approximate positions of the local extreme values. 
These should be consisten with the run length otherwise 
the result will be nonsensical. Should you wish to use
this option then you should first run the macro
without it. The item xb of the output list gives 
the acceptable limits of the local extreme values. You
can then specify the positions within these limits.}
  \item{alpha}{Quantile determining the acceptable run length.}
  \item{r}{Acceptable run length: Overrides alpha if not 0}
  \item{mr}{mr=0 minimizes the run length consistent with the
number of local extreme values found for the specified 
run length. mr=1 disables the option.}
}
\value{
  \item{l1    }{lower bounds}
  \item{u1    }{upper bounds}
  \item{l2    }{lower bound with specified extremes: the default choices for
the positions of the local extreme values are the mid-points
of the intervals specified by xb above.}
  \item{u2    }{upper bound with specified extremes}
  \item{f     }{function between l2 and u2 satisfying run condition}
  \item{xb    }{bounds for location of extremes: the position of the ith
extreme value lies between xb[2*i-1] and xb[2*i]}
  \item{nx    }{number of extremes}
  \item{r     }{run length: may differ from specified if mr=1}
}
\references{Davies, P. L. (1995) Data features. Statistica Neerlandica 49,185-245.

Davies, P. L. and Kovac, A. (2001) Local Extremes, Runs, Strings and Multiresolution (with discussion) Annals of Statistics. 29. p1-65}

\author{Laurie Davies \email{Laurie.Davies@uni-essen.de}}
\note{IN GENERAL THE MEAN OF THE BOUNDS l2 AND u2 (l2+u2)/2
GIVES A BETTER REGRESSION FUNCTION THAN f. HOWEVER THIS
FUNCTION IS INFINITE AT THE TWO ENDPOINTS AND AT LOCAL EXTREME
VALUES. IN THESE INTERVALS IT CAN BE REPLACED BY ANY VALUES
WHICH DO NOT ALTER THE NUMBER OF LOCAL EXTREME VALUES. THE
MEDIAN OF THE y-VALUES IN THESE INTERVALS IS A REASONABLE 
CHOICE. }

\seealso{\code{\link{mintvmon}},\code{\link{pmreg}},\code{\link{l1pmreg}}}
\examples{
}
\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ regression }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line

\eof
\name{ftnonpar-internal}
\alias{genmrcheck}
\alias{genstring}
\alias{kuipdiffbounds}
\alias{kuipdiffbounds.x}
\alias{multiwdwr}
\alias{tautstring}
\title{Internal ftnonpar functions}
\description{Internal ftnonpar functions}
\usage{
genmrcheck(res,thresh=-1,sigma=1,DYADIC=FALSE,beta=0.5,method=1,thr.const=2)
genstring(y,lambda,beta=0.5,method=1)
kuipdiffbounds
kuipdiffbounds.x
multiwdwr(y, thresh,firstwidth=1)
tautstring(ttt, fdist, y.low, y.up, y1 = 0.5 * (y.low[1] + y.up[1]),
    yn = 0.5 * (y.low[length(x)] + y.up[length(x)]),extrmean=TRUE)
}
\details{These are not to be called by the user}
\keyword{internal}
\eof
\name{kkuip}
\alias{kkuip}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Generalized Kuiper Metrics}
\description{
Calculates the generalized k-th Kuiper metric
}
\usage{
kkuip(x, k=1)
}
\arguments{
  \item{x}{Data vector}
  \item{k}{Number of intervals to be used for the generalized Kuiper
metric. The usual Kuiper metric is obtained by the default value 1.}
}
\value{
  \item{metric}{Value of the metric}
  \item{a     }{The left borders of the intervals where the maximum is obtained.}
  \item{b     }{The right borders of the intervals where the maximum is obtained.}
}
\references{Davies, P. L. and Kovac, A. (2001) Densities, Spectral Densities and Modality}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{pmden}}}

\examples{
aaa <- rclaw(500)
kkuip(aaa,9)
}
\keyword{univar  }% at least one, from doc/KEYWORDS
\eof
\name{l1pmreg}
\alias{l1pmreg}
\alias{quantpmreg}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Piecewise monotone nonparameric quantile regression}
\description{
Applies the generalized taut string method to quantile regression.   
}
\usage{
quantpmreg(y, beta = 0.5, squeezing.factor = 0.5, verbose = F, localsqueezing = T, DYADIC = T, thr.const = 2, extrema.nr = -1, bandwidth = -1)
l1pmreg(y, squeezing.factor = 0.5, verbose = F, localsqueezing = T, DYADIC = T, thr.const = 2, extrema.nr = -1, bandwidth = -1)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{observed values (ordered by value of independent variable)}
  \item{beta}{quantile. The default is 0.5 which corresponds to 
the robust taut string.}
  \item{squeezing.factor}{The amount of decrement applied to the bandwidthes}
  \item{verbose}{logical, if T progress (for each iteration) is illustrated grahically}
  \item{localsqueezing}{logical, if T (default) the bandwidth is changed
locally.}
  \item{DYADIC}{logical, if T (default) the multiresolution criterion
is only verified on intervals with dyadic endpoints.}
  \item{thr.const}{smoothing parameter for the multiresoultion criterion
(should be approximately 2)}
  \item{extrema.nr}{if set to a positive integer an approximation with
the specified number of local extreme values is calculated}
  \item{bandwidth}{if set to a positive value the specified bandwidth is
used instead of the multiresolution criterion.}
}
\value{
A list with components
  \item{y}{The approximation of the given data}
  \item{lambda}{The final values of lambda}
  \item{nmax}{Number of local extreme values}
}
\references{D\"umbgen, L. and Kovac, A. (2003) Extensions of smoothing via taut strings}     
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{pmreg}},\code{\link{frun}}}
\examples{
}
\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ regression }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line
\keyword{ robust }% __ONLY ONE__ keyword per line

\eof
\name{mintvmon}
\alias{mintvmon}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Minimization of total variation}
\description{
Finds a function vector which minimizes the total variation of 
the function or a derivative under multiresolution constraints
and monotonicity and convexity constraints.
}
\usage{
mintvmon(y, sigma = -1, DYADIC = T, thresh = -1, method = 2, MONCONST = T, CONVCONST = F)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{y}{observed values (ordered by value of independent variable).}
  \item{sigma}{if set to a positive value the standard deviation is set to sigma and not estimated from the data}
  \item{DYADIC}{logical, if T (default) the multiresolution constraints are only verifeid on intervals with dyadic endpoints}
  \item{thresh}{if set to a positive value other thresholds for the multiresolution criterion than the default sqrt(2*log(n))*sigma can be used.}
  \item{method}{Number of derivative the total variation of which is minimzed. Possible values are 0,1,2. Higher values lead to numerical inconsistencies.}
  \item{MONCONST}{logical, if T (default) additional monotonicty constraints are gathered from minimzing the total variation of f. Makes only sense, if method is 1 or 2.} 
  \item{CONVCONST}{logical, if T (default) additional convexity constraints are gathered from minimzing the total variation of f'. Makes only sense, if method is 2.}

}
\value{
A list with components
  \item{y        }{The approximation of the given data}           
  \item{derivsign}{Vector of 1 and -1, monotonicty constraints used if
MONCONST was true}
  \item{secsign  }{Vector of 1 and -1, convexity constraints used if
CONVCONST was true}
  \item{jact     }{Left endpoints of active multiresolution constraints
for the final approximation}
  \item{kact     }{Right endpoints of active multiresolution constraints
for the final approximation}
  \item{signact  }{Vector of 1 and -1, gives for each active multiresolution
constraints, if the residuals on that interval attain upper or lower bound}
  \item{pl       }{Left endpoint of piecewise constant intervals of the 
derivative of f being minmized}
  \item{pr       }{Right  endpoint of piecewise constant intervals of the
derivative of f being minmized}
}
\references{Kovac, A. (2003) Minimizing Total Variation under Multiresolution Conditions}
\author{Arne Kovac}

\seealso{\code{\link{pmreg}}}
\examples{
data(djdata)
djdoppler.tv0 <- mintvmon(djdoppler,method=0)
djdoppler.tv1 <- mintvmon(djdoppler,method=1)
djdoppler.tv2 <- mintvmon(djdoppler)
par(mfrow=c(2,2))
plot(djdoppler,col="lightgrey")
plot(djdoppler,col="lightgrey")
lines(djdoppler.tv0$y,col="blue")
plot(djdoppler,col="lightgrey")
lines(djdoppler.tv1$y,col="green")
plot(djdoppler,col="lightgrey")
lines(djdoppler.tv2$y,col="red")
}
\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line

\eof
\name{pmden}
\alias{pmden}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Piecewise monotone density estimation with taut strings}
\description{
Applies the taut string method to one-dimensional data.
}
\usage{
pmden(x, DISCR=F,verbose = F, bandwidth=-1, extrema.nr = -1, accuracy = mad(x)/1000,  extrema.mean = T,maxkuipnr=19,asympbounds=F, tolerance = 0.001)

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{observed values}
  \item{DISCR}{logical, if T a discrete density is fitted}
  \item{verbose}{logical, if T progress (for each iteration) is illustrated grahically}
  \item{bandwidth}{if set to a positive value the specified bandwidth is
used instead of the automatic criterion based on generalized Kuiper metrics.}
  \item{extrema.nr}{if set to a positive integer an approximation with
the specified number of local extreme values is calculated}
  \item{accuracy}{Precision of the data. Handling of identical observations
depends on this parameter.}
  \item{extrema.mean}{logical, if T the value at the local extrema is changed to the mean frequency of observations on that interval}
  \item{maxkuipnr}{The order of the highest generalized Kuiper metric used for the
automatic choice of the bandwidth}
  \item{asympbounds}{If set to T asymptotic bounds derived from a Brwonian Bridge are used
for the Kuiper criterion. Otherwise simulated bounds for various sample sizes are interpolated
for the size of the data x}
  \item{tolerance}{Accuracy used for the determination of the bandwidth
when extrema.nr is greater than 0.}
}
\value{
  \item{y}{values of the density approximation between the observations}
  \item{widthes}{bandwidth used for the taut string approximation}
  \item{nmax}{number of local extreme values}
  \item{ind}{indices of knots points of the taut string}
  \item{trans}{taut string at the observations, should look like uniform
noise}
}
\references{Davies, P. L. and Kovac, A. (2003) Densities, Spectral Densities and Modality}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{pmreg}},\code{\link{l1pmreg}},\code{\link{pmspec}}}

\examples{
aaa <- rclaw(500)
pmden(aaa,verb=TRUE)$n
}
\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line

\eof
\name{pmlogreg}
\alias{pmlogreg}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Piecewise monotone logistic regression with taut strings}
\description{
Applies the taut string method to binary data.
}
\usage{
pmlogreg(y, thr.const=2.5, verbose=F, extrema.nr=-1, bandwidth=-1, 
localsqueezing=T, squeezing.factor=0.5, tolerance=0.001,extrema.mean=T)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{y}{observed values (ordered by value of independent variable)}
  \item{thr.const}{smoothing parameter for the multiresolution criterion
(should be approximately 2.5)}
  \item{verbose}{logical, if T progress (for each iteration) is illustrated grahically}
  \item{extrema.nr}{if set to a positive integer an approximation with
the specified number of local extreme values is calculated}
  \item{bandwidth}{if set to a positive value the specified bandwidth is 
used instead of the multiresolution criterion.}
  \item{localsqueezing}{logical, if T (default) the bandwidth is changed
locally.}
  \item{squeezing.factor}{The amount of decrement applied to the bandwidthes}
  \item{tolerance}{Accuracy used for the determination of the bandwidth
when extrema.nr is greater than 0.}
  \item{extrema.mean}{logical, if T (default) the value of the taut string
approximation at local extreme values is set to the mean of the observations
on the interval where the extremum is taken.}
}
\value{
A list with components
  \item{y}{The approximation of the given data}
  \item{widthes}{Bandwidth used}
  \item{nmax}{Number of local extreme values}
  \item{knotsind}{Indices of knot points}
  \item{knotsy}{y-koordinates of knots of the taut string}
}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{l1pmreg}},\code{\link{pmden}},\code{\link{pmspec}}}

\examples{
aaa<-rbinom(1024,1,0.5+0.5*sin(seq(0,10*pi,len=1024)))
pmlogreg(aaa,verbose=TRUE)$n
}
\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ regression }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line

\eof
\name{pmreg}
\alias{pmreg}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Piecewise monotone regression with taut strings}
\description{
Applies the taut string method to one-dimensional data.
}
\usage{
pmreg(y, thr.const=2.5, verbose=F, extrema.nr=-1, bandwidth=-1, 
sigma=-1, localsqueezing=T, squeezing.factor=0.5, tolerance=0.001,
extrema.mean=T)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{y}{observed values (ordered by value of independent variable)}
  \item{thr.const}{smoothing parameter for the multiresolution criterion
(should be approximately 2.5)}
  \item{verbose}{logical, if T progress (for each iteration) is illustrated grahically}
  \item{extrema.nr}{if set to a positive integer an approximation with
the specified number of local extreme values is calculated}
  \item{bandwidth}{if set to a positive value the specified bandwidth is 
used instead of the multiresolution criterion.}
  \item{sigma}{if set to a positive value sigma the standard deviation is set to sigma and not estimated from the data}
  \item{localsqueezing}{logical, if T (default) the bandwidth is changed
locally.}
  \item{squeezing.factor}{The amount of decrement applied to the bandwidthes}
  \item{tolerance}{Accuracy used for the determination of the bandwidth
when extrema.nr is greater than 0.}
  \item{extrema.mean}{logical, if T (default) the value of the taut string
approximation at local extreme values is set to the mean of the observations
on the interval where the extremum is taken.}
}
\value{
A list with components
  \item{y}{The approximation of the given data}
  \item{sigma}{Standard deviation used}
  \item{widthes}{Bandwidth used}
  \item{nmax}{Number of local extreme values}
  \item{knotsind}{Indices of knot points}
  \item{knotsy}{y-koordinates of knots of the taut string}
}
\references{Davies, P. L. and Kovac, A. (2001) Local Extremes, Runs, Strings and Multiresolution (with discussion) Annals of Statistics. 29. p1-65}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{mintvmon}},\code{\link{l1pmreg}},\code{\link{pmden}},\code{\link{pmspec}}}

\examples{
data(djdata)
pmreg(djdoppler,verbose=TRUE)$n
}
\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ regression }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line

\eof
\name{pmspec}
\alias{pmspec}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Piecewise monotone spectral density approximation with taut strings}
\description{
Applies the taut string method to spectral densities.
}
\usage{
pmspec(x, pks=0, alpha=0.9, sqzf=0.9, mult=F, lcl=F, ln=F, fig = F, pow=10^(-2))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{data}
  \item{pks}{ if pks=0 then the number of peaks is determined
    automatically. If pks = k >0 then a density with n paeks is returned \code{pks}}
  \item{alpha}{ If pks=0 then on Gaussian test beds the number of peaks of the
    true density is at least the returned value with an asymptotic
    probability of at least alpha. If pks > 0 then the parameter is not
    operational \code{alpha} } 
  \item{sqzf}{ Squeeze factor for the taut string \code{sqzf}}
  \item{mult}{ If mult = T then rescaled empirical density is compared
    with the exponential distribution only on intervals forming a
    multiresolution scheme. If T = F then all intervals are used. If the
    sample size of the data is less than 512 then T = F is default \code{mult}}
  \item{lcl}{If lcl = T then string is calculated using local
    squeezing. If lcl = F then global squeezing is used.\code{lcl}}
  \item{fig}{If fig = T then the data are automticall plotted \code{fig}}
  \item{ln}{If fig = T and ln = T then the densities are plotted on a
    log scale. If ln = F then no transformation is performed \code{ln}}  
  \item{pow}{ Peaks with a power less than pow * total power will be ignored}
}
\details{}
\value{
  \item{edf   }{Emprical spectral density}
  \item{df    }{String density}
  \item{pks   }{Number of peaks}
  \item{ll    }{Lower boundary for string}
  \item{uu    }{Upper boundary for string}
  \item{str   }{String}
}
\references{Davies, P.L. snd Kovac, A. (2001) Local extremes, runs,
  strings and multiresolution, Annals of Statistics 29 (1) 1-65.
  Davies, P. L. and Kovac, A. (2002) Densities, Spectral Densities and Modality}
\author{Laurie Davies \email{Laurie.Davies@uni-essen.de}}
\seealso{\code{\link{pmreg}},\code{\link{l1pmreg}},\code{\link{pmden}}}

\examples{
}

\keyword{ smooth }% at least one, from doc/KEYWORDS
\keyword{ nonparametric }% __ONLY ONE__ keyword per line
\keyword{ models }% __ONLY ONE__ keyword per line
\keyword{ ts     }% __ONLY ONE__ keyword per line

\eof
\name{rclaw}
\alias{rclaw}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{The Claw Distribution}
\description{
Generates a sample from the claw distribution.}
}
\usage{
rclaw(n)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{Sample size}
}
J.S. Marron and M.P. Wand.
\newblock Exact mean integrated squared error.
\newblock {\em Annals of Statistics}, 20:712--736, 1992.
\references{Marron, J. S. and Wand, M. P. (1992) Exact mean integrated squared error}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{dclaw}}}

\examples{
aaa <- rclaw(500)
kkuip(aaa,9)
}
\keyword{ distribution  }% at least one, from doc/KEYWORDS
\eof
\name{rtennormal}
\alias{rtennormal}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mixture of ten normal distributions}
\description{
Generates a sample from a mixture of ten normal distributions.}
\usage{
rtennormal(n)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{Sample size}
}
\author{Arne Kovac \email{Arne.Kovac@uni-essen.de}}
\seealso{\code{\link{rclaw}}}

\examples{
aaa <- rtennormal(500)
kkuip(aaa,9)
}
\keyword{ distribution  }% at least one, from doc/KEYWORDS
\eof
